@@ -84,6 +84,9 @@ typedef enum {
 
 	/** Tag Item not found */
 	MPD_TAG_NOT_FOUND = -90,
+
+    /* MPD_PLALIST_LOAD_FAILED */
+    MPD_PLAYLIST_LOAD_FAILED = -100,
 	
 	/** Fatal error, something I am not sure what todo with */
 	MPD_FATAL_ERROR = -1000
@@ -389,7 +392,9 @@ typedef enum {
     /** Single mode changed */
     MPD_CST_SINGLE_MODE         = 0x400000,
     /** Consume mode changed */
-    MPD_CST_CONSUME_MODE        = 0x800000
+    MPD_CST_CONSUME_MODE        = 0x800000,
+    /** Replaygain mode changed */
+    MPD_CST_REPLAYGAIN          = 0x1000000
 } ChangedStatusType;
 
 
@@ -655,6 +660,18 @@ int mpd_server_has_idle(MpdObj *mi);
  */
 int mpd_server_tag_supported(MpdObj *mi, int tag);
 
+
+typedef enum {
+    MPD_SERVER_REPLAYGAIN_MODE_OFF = 0,
+    MPD_SERVER_REPLAYGAIN_MODE_TRACK = 1,
+    MPD_SERVER_REPLAYGAIN_MODE_ALBUM = 2,
+    MPD_SERVER_REPLAYGAIN_MODE_AUTO = 3
+}MpdServerReplaygainMode;
+
+MpdServerReplaygainMode mpd_server_get_replaygain_mode(MpdObj *mi);
+
+int mpd_server_set_replaygain_mode(MpdObj *mi, MpdServerReplaygainMode mode);
+
 #endif
 
 #ifdef __cplusplus
